@@ -17,15 +17,18 @@ class SbgError(Exception):
         self.more_info = more_info
 
     def __str__(self):
-        return self.message
+        return str(self.message)
 
 
 class ResourceNotModified(SbgError):
     def __init__(self):
         super(ResourceNotModified, self).__init__(
-            code=-1, status=-1,
-            message='No relevant changes were detected in order to update the '
-                    'resource on the server.'
+            code=-1,
+            status=-1,
+            message=(
+                'No relevant changes were detected in order to update the '
+                'resource on the server.'
+            )
         )
 
 
@@ -146,3 +149,10 @@ class ExecutionDetailsInvalidTaskType(SbgError):
         super(ExecutionDetailsInvalidTaskType, self).__init__(
             code=code, status=-1, message=message, more_info=more_info
         )
+
+
+class URITooLong(SbgError):
+    def __init__(self, code=None, message=None, more_info=None):
+        super(URITooLong, self).__init__(
+            code=code, status=414, message=message, more_info=more_info
+        )
