@@ -15,7 +15,8 @@ class User(Resource):
     _URL = {
         'me': '/user',
         'get': '/users/{id}',
-        'query': '/users'
+        'query': '/users',
+        'delete': '/users/{username}'
     }
 
     href = HrefField()
@@ -93,3 +94,14 @@ class User(Resource):
             limit=limit,
             **params
         )
+
+    def disable(self, api=None):
+        """
+        Disable user
+        :param api: Api instance.
+        :return:
+        """
+        api = api or self._API
+        api.delete(
+            url=self._URL['delete'].format(username=self.username)
+        )
